Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineViewNormal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineViewNormal.cpp	(revision 56560)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineViewNormal.cpp	(revision 56561)
@@ -141,10 +141,15 @@
     LogRel(("GUI: UIMachineViewNormal::resendSizeHint: Restoring guest size-hint for screen %d to %dx%d\n",
             (int)screenId(), sizeHint.width(), sizeHint.height()));
-    /* Temporarily restrict the size to prevent a brief resize to the
-     * framebuffer dimensions (see @a UIMachineView::sizeHint()) before
-     * the following resize() is acted upon.  Expand current limitations
-     * too. */
-    setMaximumSize(sizeHint);
-    m_sizeHintOverride = sizeHint;
+    if (uisession()->isGuestSupportsGraphics())
+    {
+        /* Temporarily restrict the size to prevent a brief resize to the
+         * framebuffer dimensions (see @a UIMachineView::sizeHint()) before
+         * the following resize() is acted upon.  Expand current limitations
+         * too. */
+        setMaximumSize(sizeHint);
+        m_sizeHintOverride = sizeHint;
+    }
+    /** @todo What if not m_bIsGuestAutoresizeEnabled?  Just let the guest start
+     *        at the default 800x600? */
     display().SetVideoModeHint(screenId(), true, false, 0, 0, sizeHint.width(), sizeHint.height(), 0);
 }
